# log module is a wrapper around third-party colorlog library
# and provides an application-level interface to a logging system.

import colorlog
import logging

from . import config

# Default python log severity levels:
# CRITICAL
# ERROR
# WARNING
# INFO
# DEBUG

LOGGER = None

class LoggingLayer:
    def __init__(self, config):
        self.loggers = {}
        logging.config.dictConfig(config)

    # Note on __getitem__:
    # __getitem__ overrides the functionality of the [] operator.
    # That means this code:
    # objinstance = LoggingLayer(...)
    # objinstance[foo] calls LoggingLayer.__getitem__(foo)
    # and returns the result.
    def __getitem__(self, k):
        logger = self.loggers.get(k)
        if not logger:
            logger = logging.getLogger(k)
            self.loggers[k] = logger
        return logger

def init_logging():
    global LOGGER
    LOGGER = LoggingLayer(config.obj.LOG_SETTINGS)

